@@ -117,10 +117,9 @@ if MYPY:
     # Use `ClientConstructor` to define the argument types of `init` and
     # `ContextManager[Any]` to tell static analyzers about the return type.
 
-    class init(ClientConstructor, ContextManager[Any]):  # noqa: N801
+    class init(ClientConstructor, _InitGuard):  # noqa: N801
         pass
 
-
 else:
     # Alias `init` for actual usage. Go through the lambda indirection to throw
     # PyCharm off of the weakly typed signature (it would otherwise discover
