@@ -2,6 +2,7 @@ import sys
 
 import pytest
 import logging
+import warnings
 
 from sentry_sdk.integrations.logging import LoggingIntegration, ignore_logger
 
@@ -136,6 +137,36 @@ def test_logging_filters(sentry_init, capture_events):
     assert event["logentry"]["message"] == "hi"
 
 
+def test_logging_captured_warnings(sentry_init, capture_events, recwarn):
+    sentry_init(
+        integrations=[LoggingIntegration(event_level="WARNING")],
+        default_integrations=False,
+    )
+    events = capture_events()
+
+    logging.captureWarnings(True)
+    warnings.warn("first")
+    warnings.warn("second")
+    logging.captureWarnings(False)
+
+    warnings.warn("third")
+
+    assert len(events) == 2
+
+    assert events[0]["level"] == "warning"
+    # Captured warnings start with the path where the warning was raised
+    assert "UserWarning: first" in events[0]["logentry"]["message"]
+    assert events[0]["logentry"]["params"] == []
+
+    assert events[1]["level"] == "warning"
+    assert "UserWarning: second" in events[1]["logentry"]["message"]
+    assert events[1]["logentry"]["params"] == []
+
+    # Using recwarn suppresses the "third" warning in the test output
+    assert len(recwarn) == 1
+    assert str(recwarn[0].message) == "third"
+
+
 def test_ignore_logger(sentry_init, capture_events):
     sentry_init(integrations=[LoggingIntegration()], default_integrations=False)
     events = capture_events()
