@@ -496,7 +496,9 @@ def test_scope_initialized_before_client(sentry_init, capture_events):
 def test_weird_chars(sentry_init, capture_events):
     sentry_init()
     events = capture_events()
+    # fmt: off
     capture_message(u"föö".encode("latin1"))
+    # fmt: on
     (event,) = events
     assert json.loads(json.dumps(event)) == event
 
@@ -812,7 +814,7 @@ def test_dict_changed_during_iteration(sentry_init, capture_events):
     "dsn",
     [
         "http://894b7d594095440f8dfea9b300e6f572@localhost:8000/2",
-        u"http://894b7d594095440f8dfea9b300e6f572@localhost:8000/2",
+        "http://894b7d594095440f8dfea9b300e6f572@localhost:8000/2",
     ],
 )
 def test_init_string_types(dsn, sentry_init):
@@ -885,3 +887,9 @@ def test_max_breadcrumbs_option(
     capture_message("dogs are great")
 
     assert len(events[0]["breadcrumbs"]["values"]) == expected_breadcrumbs
+
+
+def test_multiple_positional_args(sentry_init):
+    with pytest.raises(TypeError) as exinfo:
+        sentry_init(1, None)
+    assert "Only single positional argument is expected" in str(exinfo.value)
